dadi.TwoLocus API documentation
Description: Fitting models to data summarized by pairs of loci, incorporating both allele frequencies and linkage disequilibrium

# Module `dadi.TwoLocus`

Fitting models to data summarized by pairs of loci, incorporating both allele frequencies and linkage disequilibrium

Expand source code

    """
    Fitting models to data summarized by pairs of loci, incorporating both allele frequencies and linkage disequilibrium
    """
    from . import numerics, integration, demographics, inference, plotting, TLSpectrum_mod
    TLSpectrum = TLSpectrum_mod.TLSpectrum

## Sub-modules

`dadi.TwoLocus.TLSpectrum_mod`

  Contains triallelic Spectrum object

`dadi.TwoLocus.demographics`
`dadi.TwoLocus.inference`
`dadi.TwoLocus.integration`
`dadi.TwoLocus.numerics`

  methods for numerics of two locus diffusion - grids, transition matrices, etc

`dadi.TwoLocus.plotting`
`dadi.TwoLocus.projection_genotypes`
`dadi.TwoLocus.surface_interaction`
`dadi.TwoLocus.transition1`
`dadi.TwoLocus.transition12`
`dadi.TwoLocus.transition13`
`dadi.TwoLocus.transition1D`
`dadi.TwoLocus.transition2`
`dadi.TwoLocus.transition23`
`dadi.TwoLocus.transition3`